#!/bin/bash

# Source : http://www.mplayerhq.hu/design7/dload.html
# Packager : JP Guillemin jp.guillemin@free.fr

soft='mplayer'
softversion='1.0rc4'
packageversion='64.1'

codecs="all-20071007"

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="/tmp/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest

cd $src

# export CFLAGS="-O2 -march=$arch -mtune=$cpu"

CFLAGS= ./configure \
--prefix=/usr \
--confdir=/etc \
--enable-gui \
--enable-shm \
--codecsdir=/usr/lib/codecs \
--win32codecsdir=/usr/lib/codecs \
--xanimcodecsdir=/usr/lib/codecs \
--realcodecsdir=/usr/lib/codecs \
--enable-runtime-cpudetection \
--disable-jack \
--disable-arts \
--disable-esd \
--enable-largefiles \
--disable-smb \
--enable-theora \
--disable-gl \
--disable-sdl \
--disable-ivtv \
--disable-dvdread-internal \
--enable-dvdnav \
--enable-v4l2

make -j2 || exit
make install DESTDIR=$dest || exit

cd $dest
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded

cd $dest/usr/man
find . -name "*.?" | xargs gzip -9


# redundant
rm -rf $dest/usr/share/doc
rm -rf $dest/usr/doc/MPlayer 2> /dev/null

# Description file
mkdir -p $dest/install

cat << "EODESC" > $dest/install/slack-desc
mplayer: mplayer - a versatile media player
mplayer: 
mplayer: MPlayer is a movie and animation player that supports a wide range of
mplayer: codecs and file formats: MPEG 1/2/4, DivX 3/4/5, Windows Media 7-9,
mplayer: RealAudio/Video up to 9, Quicktime 5/6, and Vivo 1/2. It has many MMX, 
mplayer: SSE(2)/3Dnow(Ex) optimized native audio & videocodecs but allows use
mplayer: of XAnim's and RealPlayer's codec plugins, and Win32 codec DLLs. It
mplayer: can play VCD/DVD and supports subtitles. 
mplayer: 
mplayer:
mplayer: 
EODESC

# A cool SVG icon
mkdir -p $dest/usr/share/icons/hicolor/scalable/apps
cp -f $buildir/mplayer.svg $dest/usr/share/icons/hicolor/scalable/apps/
rm -rf $dest/usr/share/pixmaps

# Desktop file and launcher
mkdir -p $dest/usr/share/applications
rm -f $dest/usr/share/applications/mplayer.desktop
cat << "EOF" > $dest/usr/share/applications/mplayer.desktop
[Desktop Entry]
Version=1.0
Type=Application
Encoding=UTF-8
Name=Mplayer
GenericName=Mplayer
Comment=Multimedia player
Comment[de]=Multimedia-Player
Comment[es]=Reproductor multimedia
Comment[fr]=Lecteur multimedia
Comment[it]=Lettore multimediale
Icon=mplayer
TryExec=gmplayer-launch
Exec=gmplayer-launch %F
Terminal=false
Categories=X-XFCE;Application;AudioVideo;AudioPlayer;VideoPlayer;
StartupNotify=true
MimeType=application/x-annodex;audio/x-ogg;audio/x-speex;application/x-ogg;video/x-ms-asf;video/x-ms-wmv;video/x-ms-wma;application/vnd.ms-asf;application/x-mplayer2;video/x-ms-asf-plugin;video/x-ms-wvx;video/x-ms-wax;audio/x-aiff;audio/aiff;audio/x-pn-aiff;audio/x-realaudio;audio/basic;audio/x-basic;audio/x-pn-au;audio/x-wav;audio/wav;audio/x-pn-wav;audio/x-pn-windows-acm;video/msvideo;video/x-msvideo;video/quicktime;video/x-quicktime;audio/x-m4a;application/x-quicktimeplayer;video/x-flic;audio/x-pn-realaudio;audio/x-pn-realaudio-plugin;audio/x-real-audio;application/vnd.rn-realmedia;video/mkv;audio/x-8svx;audio/8svx;audio/x-16sv;audio/168sv;image/x-ilbm;image/ilbm;video/x-anim;video/anim;video/mpeg;video/x-mpeg;audio/mpeg2;audio/x-mpeg2;audio/mpeg3;audio/x-mpeg3;audio/mpeg;audio/x-mpeg;audio/x-mpegurl;audio/mpegurl;audio/mp3;audio/x-mp3;application/x-flac;
EOF

cat << "EOL" > $dest/usr/bin/gmplayer-launch
#!/bin/bash
if [ "$1" ] ; then 
	killall -u $USER -9 gmplayer
	gmplayer "$1" &
else
	ps x | grep -q ":[0-9]* g\?mplayer" || gmplayer &
fi
EOL

chmod 755 $dest/usr/bin/gmplayer-launch
chmod +t $dest/usr/bin/mplayer

# Documentation
cd $src
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS COPYING README INSTALL ChangeLog LICENSE TODO FAQ NEWS $dest/usr/doc/$soft-$softversion
mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion


# Skins
mkdir -p $dest/usr/share/mplayer/skins
cp -rf $buildir/skins/proton $dest/usr/share/mplayer/skins
cp -rf $buildir/skins/Blue $dest/usr/share/mplayer/skins
( cd $dest/usr/share/mplayer/skins ; unlink default || rm -rf default ; ln -s proton default )

# Install the default font
cd $buildir 
rm -rf $buildir/font-arial-iso-8859-1
mkdir -p $dest/usr/share/mplayer/font
tar -xvf $buildir/font-arial-iso-8859-1.tar.bz2
cp -f $buildir/font-arial-iso-8859-1/font-arial-14-iso-8859-1/* $dest/usr/share/mplayer/font
rm -rf $buildir/font-arial-iso-8859-1

# Firefox plugin
cd $buildir 
rm -rf mplayerplug-in-3.55
tar -xvf  mplayerplug-in-3.55.tar.gz

cd mplayerplug-in-3.55
export PATH=$PATH:$buildir/gecko-sdk/bin
./configure \
--prefix=/usr \
--with-mozilla-home=/usr/lib/iceweasel \
--with-gecko-sdk=$buildir/gecko-sdk --disable-gtk1 || exit
make
strip mplayerplug-in*.so
make install DESTDIR=$dest

mkdir -p $dest/usr/lib/iceweasel/plugins
mkdir -p $dest/usr/lib/iceweasel/components
cp -pf $dest/usr/lib/mozilla/plugins/mplayerplug-in*.so $dest/usr/lib/iceweasel/plugins
cp -pf $dest/usr/lib/mozilla/plugins/mplayerplug-in*.xpt $dest/usr/lib/iceweasel/components
rm -rf $dest/usr/lib/mozilla

cd $buildir
rm -rf mplayerplug-in-3.55

# Codecs
cd $buildir
tar -xvf $codecs.tar.bz2
mkdir -p $dest/usr/lib/codecs
cp -rf $buildir/$codecs/* $dest/usr/lib/codecs
chown -R root:root $dest/usr/lib/codecs
chmod -R 755 $dest/usr/lib/codecs
rm -rf $buildir/$codecs

# fix permissions and ownership
cd $dest
chown -R root:root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Packaging
cd $dest
makepkg -l y -c n $dest.tlz

# cleanup
rm -rf $dest
rm -rf $src
